@@ -148,7 +148,13 @@ def initdb(session=None,createdefault=False,engine = None):
 
         permissionmap = __createPermissions(session,permissions)
         l.debug("permission map:{}".format(permissionmap))
-        groupmap = __createGroups(session, Conf.group2create + ["useradmin=edituser,listuser,login","{}={}".format(constants.SYSADMINGROUP,constants.SYSADMINPERM)] , permissionmap)
+        groupmap = __createGroups(session, Conf.group2create + 
+            [
+                "useradmin=edituser,listuser,login",
+                "signeduser=login",
+                "{}={}".format(constants.SYSADMINGROUP,constants.SYSADMINPERM)
+            ] 
+            , permissionmap)
         l.debug("group map:{}".format(groupmap))
         if Conf.adminname:
             root = __createUsers(session,[Conf.adminname+"="+constants.SYSADMINGROUP],groupmap,Conf.adminpass if Conf.adminpass else None)
