@@ -50,7 +50,8 @@ def configRoutes(config,Conf):
   #    renderer=Conf.changepasswordtemplate)
 
   if Conf.forbiddentologin:
-      config.add_forbidden_view(ForbiddenRoute,attr='login',renderer=Conf.logintemplate)
+      config.add_forbidden_view(AuthController,attr='login',renderer=Conf.logintemplate)
+      #config.add_forbidden_view(ForbiddenRoute,attr='login',renderer=Conf.logintemplate)
   
   config.add_view(AuthController,attr='listUser',route_name="ppss:user:list",
       permission="listuser", renderer=Conf.listusertemplate)
