@@ -9,7 +9,7 @@ from ..constants import Conf
 from ..ppss_auth_utils import checkPassword,_,__
 from ..models import PPSsuser,PPSsgroup,PPSspermission,constants
 
-from pyramid.view import view_config,forbidden_view_config
+from pyramid.view import view_defaults,view_config,forbidden_view_config
 from pyramid.httpexceptions import HTTPFound, HTTPNotFound
 from beaker.cache import cache_region
 from sqlalchemy.exc import InvalidRequestError
@@ -81,6 +81,18 @@ class ACLRoot(object):
         ACLRoot.__acl__ = aclb.buildACL()
 
 
+class ForbiddenRoute():
+    def init(self,request):
+        self.request = request
+
+
+    def login(self):
+        authcontroller = AuthController(self.request)
+        return {}
+        #authcontroller.login()
+
+
+@view_defaults(require_csrf=True)
 class AuthController():
 
     def getUserById(self,userid):
